VertexInfo - Rabbyt Reference

Documentation Index | From module rabbyt.vertexarrays.

# VertexInfo

Provides an interface to a single vertex in a `VertexArray` object.

You probably won't ever want to instance this class yourself. Instead, use "`vertex_array[index]`".

There are a number of properties for modifing the vertex data:

> `x`, `y`, `u`, `v`, `red`, `green`, `blue`, `alpha`

You can also use these shortcuts to read/write multiple values at a time:

> `xy`, `uv`, `rgb`, `rgba`

For example:

    vertex_array[index].x += 5
    vertex_array[index].rgb = 1.0, 0.0, 0.0

And just in case if it's not obvious, `u` and `v` are the texture coordinates.

## Methods

### check_index

check_index()

Checks to make sure that the stored index is valid. `IndexError` is raised if it isn't.

## Properties

### alpha

### blue

### green

### index

### red

### rgb

### rgba

### u

### uv

### v

### x

### xy

### y